"""create users table

Revision ID: d100f32b0d1f
Revises: 
Create Date: 2024-08-31 14:27:05.188218

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '001'
down_revision: Union[str, None] = None
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None
from alembic import op
from sqlalchemy import (
Column, DateTime, ForeignKey, Integer, String
)

from sqlalchemy.engine import reflection

def upgrade() -> None:
    conn = op.get_bind()
    inspect_obj = reflection.Inspector.from_engine(conn)
    tables = inspect_obj.get_table_names()
    if 'users' not in tables:
        op.create_table(
            'users',
            Column('id', Integer, primary_key=True, nullable=False),
            Column('username', String(255), nullable=False),
            Column('email', String(255), nullable=False),
            Column('password', String(255), nullable=False),

        )


def downgrade() -> None:
    raise NotImplementedError('downgrade is not yet implemented.')



from user_service.users.model.api import session
from user_service.users.model import models

class UserRepository(object):
    def __init__(self):
        self.session = session

    def users_list(self):
        return self.session.query(
            models.UserTable).all()

    def users_get(self, user_name):
        return self.session.query(
            models.UserTable).filter_by(username=user_name).first()

    def users_delete(self, user_id):
        (self.session.query(
            models.UserTable).
         filter_by(id=user_id).delete())
        self.session.commit()


    def users_create(self, values):
        user = models.UserTable().set_user(values)
        self.session.add(user)
        self.session.commit()
        return user

    def users_update(self, user_id, user):
        (self.session.query(
            models.User).
         filter_by(id=user_id).update(user))
        self.session.commit()
        return user


db_api = UserRepository()


from user_service.users.repository import user_repository
from user_service.users.repository.user import User


class LoginService(object):
    def __init__(self):
        self.dbapi = user_repository.db_api

    def validate_login(self, user: str, email:str, password:str) -> bool:
        """
        This is Business login service for Login.
        :param user:
        :param email:
        :param password:
        :return:
        """
        try:
            user_obj = User(username=user,
                            email=email, password=password)
            if user_obj.is_exists():
                return "Login successful."
            return "User does not exist. please register First."
        except Exception as ex:
            return False



from fastapi import Request

from fastapi import FastAPI
from user_service.users.service.login_service import LoginService
from user_service.users.service.register_service import RegisterService
from user_service.users.model.models import UserTableSchema

app = FastAPI()


@app.get("/api/user/validate/{name}")
async def root(name: str):
    user = LoginService().validate_login(name, email='', password='')
    return {"message": user}

@app.post("/api/user/register")
async def register(user: UserTableSchema):
    if RegisterService().register_user(user):
        return "User registered"




from user_service.users.repository.user import User

class RegisterService(object):
    def __init__(self):
        pass

    def register_user(self, user):
        if User().user_create(user):
            return "Registered successfully."
        return "User already exists."


from setuptools import setup, find_namespace_packages, find_packages
import re
import pathlib
import pkg_resources

requirements = [
"annotated-types==0.7.0",
"anyio==4.4.0",
"certifi==2024.7.4",
"click==8.1.7",
"dnspython==2.6.1",
"email_validator==2.2.0",
"fastapi==0.112.2",
"fastapi-cli==0.0.5",
"h11==0.14.0",
"httpcore==1.0.5",
"httptools==0.6.1",
"httpx==0.27.2",
"idna==3.8",
"Jinja2==3.1.4",
"markdown-it-py==3.0.0",
"MarkupSafe==2.1.5",
"mdurl==0.1.2",
"pydantic==2.8.2",
"pydantic_core==2.20.1",
"Pygments==2.18.0",
"python-dotenv==1.0.1",
"python-multipart==0.0.9",
"PyYAML==6.0.2",
"rich==13.8.0",
"shellingham==1.5.4",
"sniffio==1.3.1",
"sqlalchemy==1.3.20",
"starlette==0.38.2",
"typer==0.12.5",
"typing_extensions==4.12.2",
"uvicorn==0.30.6",
"uvloop==0.20.0",
"watchfiles==0.24.0",
"websockets==13.0.1"

    ]
# Retrieve package list
PACKAGES = (find_namespace_packages(include=["user*"], exclude=['tests']))

# Add extra virtual shortened package for each of namespace_pkgs
namespace_pkgs = ["user_service"]

# Run python setup
setup(
    name="user_service",
    version="1.0.17",
    description=(
        "user service pip package"
    ),
    install_requires=requirements,
    include_package_data=True,
    packages=PACKAGES,
)


from user_service.users.repository.user_repository import db_api
from user_service.users.model.models import UserTable

class User(object):
    def __init__(self, username=None, email=None, password=None):
        self.username = username
        self.email = email
        self.password = password
        self.db = db_api

    def user_create(self, values):
        self.db.users_create(values)
        return True

    def is_exists(self):
        if  (self.username in
                [self.db.users_get(self.username).username]):
            return True
        return False





from sqlalchemy import create_engine
from sqlalchemy.orm import (Session)
from sqlalchemy import select

from abc import ABC, abstractmethod

class IDBDriver(ABC):
    @abstractmethod
    def connect(self):
        pass
    @abstractmethod
    def disconnect(self):
        pass
    @abstractmethod
    def generate_driver_url(self):
        pass

class MySQLDriver(IDBDriver):
    def __init__(self, user_name, password, database, host, port):
        self.__driver = "mysql+pymysql://"
        self.__user_name = user_name
        self.__password = password
        self.__port = port
        self.database = database
        self.host = host
        self.session = self.connect()
    def generate_driver_url(self):
        url = (self.__driver + self.__user_name + ":" +
               self.__password + "@" + self.host + ":" +
               self.__port + "/" + self.database)
        return url

    def connect(self):
        sess = None
        try:
            engine = create_engine(self.generate_driver_url())
            sess = Session(engine)
            return sess
        except Exception as ex:
            print(ex)
        finally:
            sess.close()

    def disconnect(self):
        pass

session = MySQLDriver('root',
                      password='strong_password',
                      database='users',
                      host='192.168.1.33',
                      port='3307').connect()





import uuid
from typing import List
from typing import Optional
from sqlalchemy import ForeignKey
from sqlalchemy import String
from sqlalchemy.orm import DeclarativeBase
from sqlalchemy.orm import Mapped
from sqlalchemy.orm import mapped_column
from sqlalchemy.orm import relationship
from pydantic import BaseModel

class Base(DeclarativeBase):
    pass

class UserTable(Base):
    __tablename__ = "users"
    id: Mapped[int] = mapped_column(primary_key=True)
    username: Mapped[str] = mapped_column(String(30))
    email: Mapped[Optional[str]]
    password: Mapped[Optional[str]]

    def set_user(self, values):
        self.username = values.username
        self.email = values.email
        self.password = values.password

    def __repr__(self) -> str:
        return f"User(id={self.id!r}, username={self.username!r}, email={self.email!r}, password={self.password!r})"

class UserTableSchema(BaseModel):
    username: str
    email: str
    password: str



